@@ -232,7 +232,7 @@ class ServerlessClusterFromSnapshot(
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="clusterArn")
     def cluster_arn(self) -> builtins.str:
         '''(deprecated) The ARN of the cluster.
@@ -241,7 +241,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(builtins.str, jsii.get(self, "clusterArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="clusterEndpoint")
     def cluster_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
         '''(deprecated) The endpoint to use for read/write operations.
@@ -250,7 +250,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterEndpoint"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="clusterIdentifier")
     def cluster_identifier(self) -> builtins.str:
         '''(deprecated) Identifier of the cluster.
@@ -259,7 +259,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(builtins.str, jsii.get(self, "clusterIdentifier"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="clusterReadEndpoint")
     def cluster_read_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
         '''(deprecated) The endpoint to use for read/write operations.
@@ -268,7 +268,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterReadEndpoint"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connections")
     def connections(self) -> aws_cdk.aws_ec2.Connections:
         '''(deprecated) Access to the network connections.
@@ -277,7 +277,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="secret")
     def secret(self) -> typing.Optional[aws_cdk.aws_secretsmanager.ISecret]:
         '''(deprecated) The secret attached to this cluster.
@@ -286,7 +286,7 @@ class ServerlessClusterFromSnapshot(
         '''
         return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.ISecret], jsii.get(self, "secret"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableDataApi")
     def _enable_data_api(self) -> typing.Optional[builtins.bool]:
         '''
@@ -367,9 +367,9 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         if isinstance(scaling, dict):
-            scaling = aws_cdk.aws_rds.ServerlessScalingOptions(**scaling)
+            scaling = ServerlessScalingOptions(**scaling)
         if isinstance(vpc_subnets, dict):
-            vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+            vpc_subnets = SubnetSelection(**vpc_subnets)
         if __debug__:
             type_hints = typing.get_type_hints(ServerlessClusterFromSnapshotProps.__init__)
             check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
